# pyspring
[![Travis build status](https://img.shields.io/travis/com/harens/pyspring.svg?style=for-the-badge)](https://travis-ci.com/harens/pyspring) 
[![Latest PyPi release version number](https://img.shields.io/pypi/v/pyspring.svg?logoColor=violet&style=for-the-badge)](https://pypi.org/project/pyspring/)
[![PyPi format](https://img.shields.io/pypi/format/pyspring.svg?style=for-the-badge)](https://pypi.org/project/pyspring/)
[![Current state (Alpha/Beta/Stable etc.)](https://img.shields.io/pypi/status/pyspring.svg?style=for-the-badge)](https://pypi.org/project/pyspring/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/pyspring.svg?style=for-the-badge)](https://pypi.org/project/pyspring/)
<br>
<br>
*Functions that function!*

## Installation
```shell
pip install pyspring
```
Or download the project [here](https://github.com/harens/pyspring/archive/master.zip)

## Tests
The tests folder can be found [here](https://github.com/harens/pyspring/tree/master/tests)

You can run the tests by running `python tests/tests.py`

## License
This project is licensed under the [GNU General Public License v3.0](https://github.com/harens/pyspring/blob/master/LICENSE)
